# Dyn-Viz

This package contains the common drawing utilities used among the ``dyn`` package suite.

## 📝 Citation

If you use Dyn-Viz in your research, please use the following BibTeX entry:

```
Brisson, L., Bothorel, C., & Duminy, N. (2025). DynBenchmark: Customizable GroundTruths
to Benchmark Community Detection and Tracking in Temporal Networks, France's International Conference on Complex Systems (FRCCS 2025), Bordeaux, France
```

BibTeX:

```bibtex
@inproceedings{brisson2025dynbenchmark,
  title={DynBenchmark: Customizable Ground Truths to Benchmark Community Detection and Tracking in Temporal Networks},
  author={Brisson, Laurent and Bothorel, Cécile and Duminy, Nicolas},
  booktitle={France's International Conference on Complex Systems},
  year={2025},
  publisher={Springer}
}
```

## 👥 Contributing

This package is growing continuously and contributions are welcomed.
Contributions can come in the form of new features, bug fixes, documentation improvements
or any combination thereof.

If you want to contribute to this package, please read the [Contributing guidelines](https://gitlab.com/decide.imt-atlantique/dyn/viz/-/blob/main/doc/contributing).
If you have any new ideas or have found bugs, feel free to [create an issue](https://gitlab.com/decide.imt-atlantique/dyn/viz/-/issues/new).
Finally, any contribution must be proposed for integration as a [Merge Request](https://gitlab.com/decide.imt-atlantique/dyn/viz/-/merge_requests/new).

Please visit our [Gitlab](https://gitlab.com/decide.imt-atlantique/dyn/viz) for more details.

## 📄 License

This software is licensed under the [European Union Public Licence (EUPL) v1.2](https://joinup.ec.europa.eu/page/eupl-text-11-12>).
For more information see [this](https://gitlab.com/decide.imt-atlantique/dyn/viz/-/blob/main/LICENSE).

